@@ -7,6 +7,6 @@ File:     __init__.py
 Describe:
 """
 from .main import SupertadSparse
-from evaluation import Evaluate
+from .evaluation import Evaluate
 
 name = 'SuperTLD'
\ No newline at end of file
